@@ -25,3 +25,7 @@ CREATE FUNCTION mroonga_snippet_html RETURNS STRING
 DROP FUNCTION IF EXISTS mroonga_normalize;
 CREATE FUNCTION mroonga_normalize RETURNS STRING
   SONAME 'ha_mroonga.so';
+
+DROP FUNCTION IF EXISTS mroonga_highlight_html;
+CREATE FUNCTION mroonga_highlight_html RETURNS STRING
+  SONAME 'ha_mroonga.so';
